# ref-metrics-esmvaltool

Use [ESMValTool](https://esmvaltool.org/) as a REF metrics provider.

To use this, install ESMValTool and then install the REF into the same conda
environment.

See [running-metrics-locally](https://cmip-ref.readthedocs.io/en/latest/how-to-guides/running-metrics-locally/) for usage instructions.
